summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneycombo.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneycombo.h')
-rw-r--r--kmymoney2/widgets/kmymoneycombo.h119
1 files changed, 65 insertions, 54 deletions
diff --git a/kmymoney2/widgets/kmymoneycombo.h b/kmymoney2/widgets/kmymoneycombo.h
index c85847d..f889f3e 100644
--- a/kmymoney2/widgets/kmymoneycombo.h
+++ b/kmymoney2/widgets/kmymoneycombo.h
@@ -21,8 +21,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qtimer.h>
-#include <qmutex.h>
+#include <tqtimer.h>
+#include <tqmutex.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -51,9 +51,10 @@ class kMyMoneyLineEdit;
class KMyMoneyCombo : public KComboBox
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyCombo(QWidget *w = 0, const char *name=0);
- KMyMoneyCombo(bool rw, QWidget *w = 0, const char *name=0);
+ KMyMoneyCombo(TQWidget *w = 0, const char *name=0);
+ KMyMoneyCombo(bool rw, TQWidget *w = 0, const char *name=0);
/**
* This method is used to turn on/off the hint display and to setup the appropriate text.
@@ -62,7 +63,7 @@ public:
*
* @param hint reference to text. If @a hint is empty, no hint will be shown.
*/
- void setHint(const QString& hint) const;
+ void setHint(const TQString& hint) const;
/**
* overridden for internal reasons.
@@ -88,90 +89,90 @@ public:
/**
* This method returns the ids of the currently selected items
*/
- void selectedItems(QStringList& list) const;
+ void selectedItems(TQStringList& list) const;
/**
* This method returns the id of the first selected item.
* Usage makes usually only sense when the selection mode
- * of the associated KMyMoneySelector is QListView::Single.
+ * of the associated KMyMoneySelector is TQListView::Single.
*
* @sa KMyMoneySelector::setSelectionMode()
*
* @param id reference to QString containing the id. If no item
* is selected id will be empty.
*/
- void selectedItem(QString& id) const KDE_DEPRECATED;
+ void selectedItem(TQString& id) const KDE_DEPRECATED;
/**
* This method returns the id of the first selected item.
* Usage makes usually only sense when the selection mode
- * of the associated KMyMoneySelector is QListView::Single.
+ * of the associated KMyMoneySelector is TQListView::Single.
*
* @sa KMyMoneySelector::setSelectionMode()
*
* @return reference to QString containing the id. If no item
* is selected the QString will be empty.
*/
- const QString& selectedItem(void) const { return m_id; }
+ const TQString& selectedItem(void) const { return m_id; }
/**
* This method selects the item with the respective @a id.
*
* @param id reference to QString containing the id
*/
- void setSelectedItem(const QString& id);
+ void setSelectedItem(const TQString& id);
/**
* This method checks if the position @a pos is part of the
* area of the drop down arrow.
*/
- bool isInArrowArea(const QPoint& pos) const;
+ bool isInArrowArea(const TQPoint& pos) const;
void setSuppressObjectCreation(bool suppress) { m_canCreateObjects = !suppress; }
/**
* overridden for internal reasons, no API change
*/
- void setCurrentText(const QString& txt = QString()) { KComboBox::setCurrentText(txt); }
+ void setCurrentText(const TQString& txt = TQString()) { KComboBox::setCurrentText(txt); }
/**
* overridden to set the background color of the lineedit as well
*/
- void setPaletteBackgroundColor(const QColor& color);
+ void setPaletteBackgroundColor(const TQColor& color);
/**
* Overridden to support our own completion box
*/
- QSize sizeHint() const;
+ TQSize tqsizeHint() const;
protected slots:
- virtual void slotItemSelected(const QString& id);
+ virtual void slotItemSelected(const TQString& id);
protected:
/**
* reimplemented to support our own popup widget
*/
- void mousePressEvent(QMouseEvent *e);
+ void mousePressEvent(TQMouseEvent *e);
/**
* reimplemented to support our own popup widget
*/
- void keyPressEvent(QKeyEvent *e);
+ void keyPressEvent(TQKeyEvent *e);
/**
* reimplemented to support our own popup widget
*/
- void paintEvent(QPaintEvent *);
+ void paintEvent(TQPaintEvent *);
/**
* reimplemented to support detection of new items
*/
- void focusOutEvent(QFocusEvent* );
+ void focusOutEvent(TQFocusEvent* );
/**
* set the widgets text area based on the item with the given @a id.
*/
- virtual void setCurrentTextById(const QString& id);
+ virtual void setCurrentTextById(const TQString& id);
/**
* Overridden for internal reasons, no API change
@@ -197,16 +198,16 @@ protected:
/**
* The currently selected item
*/
- QString m_id;
+ TQString m_id;
signals:
- void itemSelected(const QString& id);
+ void itemSelected(const TQString& id);
void objectCreation(bool);
- void createItem(const QString&, QString&);
+ void createItem(const TQString&, TQString&);
private:
- QTimer m_timer;
- QMutex m_focusMutex;
+ TQTimer m_timer;
+ TQMutex m_focusMutex;
/**
* Flag to control object creation. Use setSuppressObjectCreation()
* to modify it's setting. Defaults to @a false.
@@ -227,15 +228,16 @@ private:
class KMyMoneyReconcileCombo : public KMyMoneyCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyReconcileCombo(QWidget *w = 0, const char *name=0);
+ KMyMoneyReconcileCombo(TQWidget *w = 0, const char *name=0);
void setState(MyMoneySplit::reconcileFlagE state);
MyMoneySplit::reconcileFlagE state(void) const;
void removeDontCare(void);
protected slots:
- void slotSetState(const QString&);
+ void slotSetState(const TQString&);
};
/**
@@ -248,15 +250,16 @@ protected slots:
class KMyMoneyComboAction : public KMyMoneyCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyComboAction(QWidget *w = 0, const char *name=0);
+ KMyMoneyComboAction(TQWidget *w = 0, const char *name=0);
void setAction(int state);
int action(void) const;
void protectItem(int id, bool protect);
protected slots:
- void slotSetAction(const QString&);
+ void slotSetAction(const TQString&);
signals:
void actionSelected(int);
@@ -270,19 +273,20 @@ signals:
class KMyMoneyCashFlowCombo : public KMyMoneyCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Create a combo box that contains the entries "Pay to", "From" and
* " " for don't care.
*/
- KMyMoneyCashFlowCombo(QWidget *w = 0, const char *name=0, MyMoneyAccount::accountTypeE type = MyMoneyAccount::Asset);
+ KMyMoneyCashFlowCombo(TQWidget *w = 0, const char *name=0, MyMoneyAccount::accountTypeE type = MyMoneyAccount::Asset);
void setDirection(KMyMoneyRegister::CashFlowDirection dir);
KMyMoneyRegister::CashFlowDirection direction(void) const { return m_dir; }
void removeDontCare(void);
protected slots:
- void slotSetDirection(const QString& id);
+ void slotSetDirection(const TQString& id);
signals:
void directionSelected(KMyMoneyRegister::CashFlowDirection);
@@ -299,17 +303,18 @@ private:
class KMyMoneyActivityCombo : public KMyMoneyCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Create a combo box that contains the entries "Buy", "Sell" etc.
*/
- KMyMoneyActivityCombo(QWidget *w = 0, const char *name=0);
+ KMyMoneyActivityCombo(TQWidget *w = 0, const char *name=0);
void setActivity(MyMoneySplit::investTransactionTypeE activity);
MyMoneySplit::investTransactionTypeE activity(void) const { return m_activity; }
protected slots:
- void slotSetActivity(const QString& id);
+ void slotSetActivity(const TQString& id);
signals:
void activitySelected(MyMoneySplit::investTransactionTypeE);
@@ -327,7 +332,7 @@ private:
* If any match is found a list selection box is opened and the user can use
* the up/down, page-up/page-down keys or the mouse to navigate in the list. If
* a payee is selected, the selection box is closed. Other key-strokes are
* directed to the parent object to manipulate the text. The visible contents of
* the selection box is updated with every key-stroke.
*
* This object is a replacement of the kMyMoneyPayee object and should be used
@@ -338,20 +343,22 @@ private:
class KMyMoneyPayeeCombo : public KMyMoneyCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyPayeeCombo(QWidget* parent = 0, const char* name = 0);
+ KMyMoneyPayeeCombo(TQWidget* tqparent = 0, const char* name = 0);
- void loadPayees(const QValueList<MyMoneyPayee>& list);
+ void loadPayees(const TQValueList<MyMoneyPayee>& list);
};
class KMyMoneyGeneralCombo : public KComboBox
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyGeneralCombo(QWidget* parent = 0, const char* name = 0);
+ KMyMoneyGeneralCombo(TQWidget* tqparent = 0, const char* name = 0);
virtual ~KMyMoneyGeneralCombo();
- void insertItem(const QString& txt, int id, int idx = -1);
+ void insertItem(const TQString& txt, int id, int idx = -1);
void setItem(int id) KDE_DEPRECATED; // replace with setCurrentItem(id)
int item(void) const KDE_DEPRECATED; // replace with currentItem()
@@ -369,7 +376,7 @@ signals:
protected:
// prevent the caller to use the standard KComboBox insertItem function with a default idx
- void insertItem(const QString&);
+ void insertItem(const TQString&);
protected slots:
void slotChangeItem(int idx);
@@ -389,8 +396,9 @@ private:
class KMyMoneyPeriodCombo : public KMyMoneyGeneralCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyPeriodCombo(QWidget* parent = 0, const char* name = 0);
+ KMyMoneyPeriodCombo(TQWidget* tqparent = 0, const char* name = 0);
MyMoneyTransactionFilter::dateOptionE currentItem(void) const;
void setCurrentItem(MyMoneyTransactionFilter::dateOptionE id);
@@ -398,31 +406,32 @@ public:
/**
* This function returns the actual start date for the given
* period definition given by @p id. For user defined periods
* the returned value is QDate()
*/
- static QDate start(MyMoneyTransactionFilter::dateOptionE id);
+ static TQDate start(MyMoneyTransactionFilter::dateOptionE id);
/**
* This function returns the actual end date for the given
* period definition given by @p id. For user defined periods
* the returned value is QDate()
*/
- static QDate end(MyMoneyTransactionFilter::dateOptionE id);
+ static TQDate end(MyMoneyTransactionFilter::dateOptionE id);
- // static void dates(QDate& start, QDate& end, MyMoneyTransactionFilter::dateOptionE id);
+ // static void dates(TQDate& start, TQDate& end, MyMoneyTransactionFilter::dateOptionE id);
};
/**
* This class implements an occurence selector
* as a parent class for both OccurencePeriod and Frequency combos
*
* @author Colin Wright
*/
class KMyMoneyOccurenceCombo : public KMyMoneyGeneralCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyOccurenceCombo(QWidget* parent = 0, const char* name = 0);
+ KMyMoneyOccurenceCombo(TQWidget* tqparent = 0, const char* name = 0);
MyMoneySchedule::occurenceE currentItem(void) const;
};
@@ -435,8 +444,9 @@ public:
class KMyMoneyOccurencePeriodCombo : public KMyMoneyOccurenceCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyOccurencePeriodCombo(QWidget* parent = 0, const char* name = 0);
+ KMyMoneyOccurencePeriodCombo(TQWidget* tqparent = 0, const char* name = 0);
};
/**
@@ -446,8 +456,9 @@ public:
class KMyMoneyFrequencyCombo : public KMyMoneyOccurenceCombo
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyFrequencyCombo(QWidget* parent = 0, const char* name = 0);
+ KMyMoneyFrequencyCombo(TQWidget* tqparent = 0, const char* name = 0);
/**
* This method returns the number of events for the selected payment
@@ -88,90 +89,90 @@ public:
* @sa KMyMoneySelector::setSelectionMode()
*
- * @param id reference to QString containing the id. If no item
+ * @param id reference to TQString containing the id. If no item
* is selected id will be empty.
*/
@@ -88,90 +89,90 @@ public:
* @sa KMyMoneySelector::setSelectionMode()
*
- * @return reference to QString containing the id. If no item
- * is selected the QString will be empty.
+ * @return reference to TQString containing the id. If no item
+ * is selected the TQString will be empty.
*/
@@ -88,90 +89,90 @@ public:
* This method selects the item with the respective @a id.
*
- * @param id reference to QString containing the id
+ * @param id reference to TQString containing the id
*/
@@ -327,7 +332,7 @@ private:
* the up/down, page-up/page-down keys or the mouse to navigate in the list. If
* a payee is selected, the selection box is closed. Other key-strokes are
- * directed to the parent object to manipulate the text. The visible contents of
+ * directed to the tqparent object to manipulate the text. The visible contents of
* the selection box is updated with every key-stroke.
*
@@ -398,31 +406,32 @@ public:
* This function returns the actual start date for the given
* period definition given by @p id. For user defined periods
- * the returned value is QDate()
+ * the returned value is TQDate()
*/
@@ -398,31 +406,32 @@ public:
* This function returns the actual end date for the given
* period definition given by @p id. For user defined periods
- * the returned value is QDate()
+ * the returned value is TQDate()
*/
@@ -398,31 +406,32 @@ public:
/**
* This class implements an occurence selector
- * as a parent class for both OccurencePeriod and Frequency combos
+ * as a tqparent class for both OccurencePeriod and Frequency combos
*
* @author Colin Wright